==> POCSdk-1.0.52-sources.jar: com/xdja/poc/sdk/db/entity/DBGroupEntity.java <==
package com.xdja.poc.sdk.db.entity;
import android.support.annotation.Keep;

import java.io.Serializable;

/**
 * Created by Administrator on 2018/8/24.
 */
@Keep
public class DBGroupEntity implements Serializable {

    private static final long serialVersionUID = 7546438088364294003L;
    private String key;//主键
    private String userId;
    private String ownerId;//频道id
    private String activeUserId;//活跃的用户id（非自己）
    private String rooomId;
    private String roomName;
    private String memeberIds;//成员类表json字符串
    private String pinyin;//全拼
    private int onLineCount;//在线成员的人数
    private int isSilence;//1 0区分
    private int status = 0;//0 是挂断 1,空闲,2:是有人在讲话中
    private int isTopStick;//是否置顶 1 0
    private int topStickIndex;//置顶的位置索引
    private long topStickTime;//置顶的时间
    private int groupType;//频道类型:0:固定 , 1:临时
    private int channelPwdMode;//开始模式 1  0
    private int isPttKey;//1 0
    private int maxInviteMembersCount;
    private String speakerUserId;
    private String speakerUserName;
    private String userNames;//
    private String channelPwd;//频道口令
    private int totalCount;
    public DBGroupEntity() {
    }
    public String getKey() {
        return this.key;
    }
    public void setKey(String key) {
        this.key = key;
    }
    public String getUserId() {
        return this.userId;
    }
    public void setUserId(String userId) {
        this.userId = userId;
    }
    public String getOwnerId() {
        return this.ownerId;
    }
    public void setOwnerId(String ownerId) {
        this.ownerId = ownerId;
    }
    public String getActiveUserId() {
        return this.activeUserId;
    }
    public void setActiveUserId(String activeUserId) {
        this.activeUserId = activeUserId;
    }
    public String getRooomId() {
        return this.rooomId;
    }
    public void setRooomId(String rooomId) {
        this.rooomId = rooomId;
    }
    public String getRoomName() {
        return this.roomName;
    }
    public void setRoomName(String roomName) {
        this.roomName = roomName;
    }
    public String getMemeberIds() {
        return this.memeberIds;
    }
    public void setMemeberIds(String memeberIds) {
        this.memeberIds = memeberIds;
    }
    public int getOnLineCount() {
        return this.onLineCount;
    }
    public void setOnLineCount(int onLineCount) {
        this.onLineCount = onLineCount;
    }
    public String getPinyin() {
        return this.pinyin;
    }
    public void setPinyin(String pinyin) {
        this.pinyin = pinyin;
    }
    public boolean getIsSilence() {
        return this.isSilence==1?true:false;
    }
    public void setIsSilence(int isSilence) {
        this.isSilence = isSilence;
    }
    public String getSpeakerUserId() {
        return this.speakerUserId;
    }
    public void setSpeakerUserId(String speakerUserId) {
        this.speakerUserId = speakerUserId;
    }
    public String getSpeakerUserName() {
        return this.speakerUserName;
    }
    public void setSpeakerUserName(String speakerUserName) {
        this.speakerUserName = speakerUserName;
    }
    public int getStatus() {
        return this.status;
    }
    public void setStatus(int status) {
        this.status = status;
    }
    public boolean getIsTopStick() {
        return this.isTopStick==1?true:false;
    }
    public void setIsTopStick(int isTopStick) {
        this.isTopStick = isTopStick;
    }
    public int getTopStickIndex() {
        return this.topStickIndex;
    }
    public void setTopStickIndex(int topStickIndex) {
        this.topStickIndex = topStickIndex;
    }
    public long getTopStickTime() {
        return this.topStickTime;
    }
    public void setTopStickTime(long topStickTime) {
        this.topStickTime = topStickTime;
    }
    public int getGroupType() {
        return this.groupType;
    }
    public void setGroupType(int groupType) {
        this.groupType = groupType;
    }
    public String getUserNames() {
        return this.userNames;
    }
    public void setUserNames(String userNames) {
        this.userNames = userNames;
    }
    public boolean getIsPttKey() {
        return this.isPttKey==1?true:false;
    }
    public void setIsPttKey(int isPttKey) {
        this.isPttKey = isPttKey;
    }
    public String getChannelPwd() {
        return this.channelPwd;
    }
    public void setChannelPwd(String channelPwd) {
        this.channelPwd = channelPwd;
    }
    public boolean getChannelPwdMode() {
        return this.channelPwdMode==1?true:false;
    }
    public void setChannelPwdMode(int channelPwdMode) {
        this.channelPwdMode = channelPwdMode;
    }

    public int getTotalCount() {
        return totalCount;
    }

    public void setTotalCount(int totalCount) {
        this.totalCount = totalCount;
    }

    public int getMaxInviteMembersCount() {
        return maxInviteMembersCount;
    }

    public void setMaxInviteMembersCount(int maxInviteMembersCount) {
        this.maxInviteMembersCount = maxInviteMembersCount;
    }
}

==> POCSdk-1.0.103-sources.jar: com/xdja/poc/sdk/db/entity/DBGroupEntity.java <==
package com.xdja.poc.sdk.db.entity;
import android.support.annotation.Keep;

import java.io.Serializable;

/**
 * Created by Administrator on 2018/8/24.
 */
@SuppressWarnings("ALL")
@Keep
public class DBGroupEntity implements Serializable {

    private static final long serialVersionUID = 7546438088364294003L;
    private String key;//主键
    private String userId;
    private String ownerId;//频道id
    private String activeUserId;//活跃的用户id（非自己）
    private String rooomId;
    private String roomName;
    private String memeberIds;//成员类表json字符串
    private String pinyin;//全拼
    private int onLineCount;//在线成员的人数
    private int isSilence;//1 0区分
    private int status = 0;//0 是挂断 1,空闲,2:是有人在讲话中
    private int isTopStick;//是否置顶 1 0
    private int topStickIndex;//置顶的位置索引
    private long topStickTime;//置顶的时间
    private int groupType;//频道类型:0:固定 , 1:临时
    private int channelPwdMode;//开始模式 1  0
    private int isPttKey;//1 0
    private int maxInviteMembersCount;
    private String speakerUserId;
    private String speakerUserName;
    private String userNames;//
    private String channelPwd;//频道口令
    private int totalCount;
    public DBGroupEntity() {
    }
    public String getKey() {
        return this.key;
    }
    public void setKey(String key) {
        this.key = key;
    }
    public String getUserId() {
        return this.userId;
    }
    public void setUserId(String userId) {
        this.userId = userId;
    }
    public String getOwnerId() {
        return this.ownerId;
    }
    public void setOwnerId(String ownerId) {
        this.ownerId = ownerId;
    }
    public String getActiveUserId() {
        return this.activeUserId;
    }
    public void setActiveUserId(String activeUserId) {
        this.activeUserId = activeUserId;
    }
    public String getRooomId() {
        return this.rooomId;
    }
    public void setRooomId(String rooomId) {
        this.rooomId = rooomId;
    }
    public String getRoomName() {
        return this.roomName;
    }
    public void setRoomName(String roomName) {
        this.roomName = roomName;
    }
    public String getMemeberIds() {
        return this.memeberIds;
    }
    public void setMemeberIds(String memeberIds) {
        this.memeberIds = memeberIds;
    }
    public int getOnLineCount() {
        return this.onLineCount;
    }
    public void setOnLineCount(int onLineCount) {
        this.onLineCount = onLineCount;
    }
    public String getPinyin() {
        return this.pinyin;
    }
    public void setPinyin(String pinyin) {
        this.pinyin = pinyin;
    }
    public boolean getIsSilence() {
        return this.isSilence == 1;
    }
    public void setIsSilence(int isSilence) {
        this.isSilence = isSilence;
    }
    public String getSpeakerUserId() {
        return this.speakerUserId;
    }
    public void setSpeakerUserId(String speakerUserId) {
        this.speakerUserId = speakerUserId;
    }
    public String getSpeakerUserName() {
        return this.speakerUserName;
    }
    public void setSpeakerUserName(String speakerUserName) {
        this.speakerUserName = speakerUserName;
    }
    public int getStatus() {
        return this.status;
    }
    public void setStatus(int status) {
        this.status = status;
    }
    public boolean getIsTopStick() {
        return this.isTopStick == 1;
    }
    public void setIsTopStick(int isTopStick) {
        this.isTopStick = isTopStick;
    }
    public int getTopStickIndex() {
        return this.topStickIndex;
    }
    public void setTopStickIndex(int topStickIndex) {
        this.topStickIndex = topStickIndex;
    }
    public long getTopStickTime() {
        return this.topStickTime;
    }
    public void setTopStickTime(long topStickTime) {
        this.topStickTime = topStickTime;
    }
    public int getGroupType() {
        return this.groupType;
    }
    public void setGroupType(int groupType) {
        this.groupType = groupType;
    }
    public String getUserNames() {
        return this.userNames;
    }
    public void setUserNames(String userNames) {
        this.userNames = userNames;
    }
    public boolean getIsPttKey() {
        return this.isPttKey == 1;
    }
    public void setIsPttKey(int isPttKey) {
        this.isPttKey = isPttKey;
    }
    public String getChannelPwd() {
        return this.channelPwd;
    }
    public void setChannelPwd(String channelPwd) {
        this.channelPwd = channelPwd;
    }
    public boolean getChannelPwdMode() {
        return this.channelPwdMode == 1;
    }
    public void setChannelPwdMode(int channelPwdMode) {
        this.channelPwdMode = channelPwdMode;
    }

    public int getTotalCount() {
        return totalCount;
    }

    public void setTotalCount(int totalCount) {
        this.totalCount = totalCount;
    }

    public int getMaxInviteMembersCount() {
        return maxInviteMembersCount;
    }

    public void setMaxInviteMembersCount(int maxInviteMembersCount) {
        this.maxInviteMembersCount = maxInviteMembersCount;
    }
}
